@@ -925,14 +925,61 @@ Original Error: {error_message}
         # System prompt for detection
         system_prompt = """You are an intelligent document processing assistant specializing in creating interactive forms.
 
-Task: Analyze the given content block and determine if it needs to be converted to an interaction block to collect user information.
+Task: Analyze the given content block and determine if it needs to be converted to an interaction block.
 
-Judgment criteria:
-1. It requires to generate/show buttons
-2. It requires to generate/show checkboxs or multi-selection interactive elements
-3. It requires to generate/show text input box
+**CORE PRINCIPLE**: Focus on INTENT and PATTERNS, not specific keywords.
 
-If conversion is needed, generate a STANDARD interaction block format with SPECIFIC options based on the document-level instructions and context provided in the user message."""
+**CONVERSION REQUIRED when the text shows:**
+
+1. **Collection Pattern**:
+   - PATTERN: [Action verb] + [choices/options] + [storage indicator]
+   - PATTERN: Request for user input/selection/choice + destination variable
+   - PATTERN: Interactive UI request with specific options
+
+2. **Storage Indicators** (language-agnostic):
+   - Presence of target variable for NEW data: {{new_variable}}
+   - Assignment operators or arrows: →, =>, "to", "into", "as"
+   - Save/store/record semantics in ANY language
+
+3. **Interactive Intent Signals**:
+   - Imperative mood requesting user action
+   - Multiple specific options provided (not just descriptions)
+   - Form-like structure with fields to fill
+
+**DO NOT CONVERT when the text shows:**
+
+1. **Display/Reference Pattern**:
+   - PATTERN: Using {{existing_var}} + display/list/show action
+   - PATTERN: Information presentation without collection
+   - Keywords suggesting reference/viewing (regardless of language):
+     * "for reference", "供参考", "zur Referenz", "pour référence"
+     * "display", "show", "list", "罗列", "afficher", "anzeigen"
+
+2. **Information Flow**:
+   - Data flows FROM variable TO display (not from user to variable)
+   - Descriptive or explanatory content
+   - Recommendations or suggestions without explicit selection request
+
+**Language-Agnostic Examples**:
+
+❌ Don't convert (any language):
+- "Based on {{history}}, list/display/show [items] for reference"
+- "根据{{history}}的选择，罗列该朝代的皇帝或者年号，供用户参考"
+- "Selon {{history}}, afficher les empereurs pour référence"
+
+✅ Convert (any language):
+- "Ask user to select [option] and save to {{variable}}"
+- "让用户选择风格并记录到{{style}}"
+- "Create buttons: Yes/No" (implies interaction needed)
+- "Demander à l'utilisateur de choisir et enregistrer dans {{choix}}"
+
+**Decision Rule**:
+Look for the SEMANTIC INTENT, not specific words:
+- Is NEW information being COLLECTED from user? → Convert
+- Is EXISTING information being DISPLAYED to user? → Don't convert
+- When uncertain, check: Does this create a new {{variable}} or just use existing ones?
+
+If conversion is needed, generate a STANDARD interaction block format."""
 
         # User message with content and context
         # Build user prompt with document context
